package se.gawell.setrace.jersey;

import org.slf4j.MDC;

import se.gawell.setrace.logging.Logger;

import com.sun.jersey.spi.container.ContainerRequest;
import com.sun.jersey.spi.container.ContainerRequestFilter;

/**
 * Request filter that reads the http header for a request trace id.
 * If there is no request trace id present in the header one will be generated from
 * the request url.
 * 
 * The resulting request trace id is then added to MDC.
 * 
 * @author Niklas Gawell
 *
 */
class ServletRequestTraceIdRequestFiler implements ContainerRequestFilter {
	
	@Override
	public ContainerRequest filter(ContainerRequest request) {
		String requestTraceId = request.getHeaderValue(Logger.REQUEST_TRACE_ID_NAME);
		if (requestTraceId == null || requestTraceId.equals("")) {
			requestTraceId = generateRequestTraceId(request.getPath(true));
		}
		MDC.put(Logger.REQUEST_TRACE_ID_NAME, requestTraceId);
		return request;
	}

	private String generateRequestTraceId(String string) {
		return string + "_" + System.currentTimeMillis();
	}

}
